#
# spec file for package libbpf
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover_major 0
%define libname libbpf%{sover_major}
Name:           libbpf
%define version %(rpm -q --qf '%%{VERSION}' kernel-source)
Version:        %{version}
Release:        1.44
Summary:        C library for managing eBPF programs and maps
License:        LGPL-2.1-only
URL:            http://www.kernel.org/
BuildRequires:  kernel-source
BuildRequires:  libelf-devel
BuildRequires:  python3

%description
libbpf is a C library which provides API for managing eBPF programs and maps.

%package -n %{libname}
Summary:        C library for managing eBPF programs and maps

%description -n %{libname}
libbpf is a C library which provides API for managing eBPF programs and maps.

%package devel
Summary:        Development files for libbpf
Requires:       %{libname} = %{version}

%description devel
libbpf is a C library which provides API for managing eBPF programs and maps.

%prep
(cd /usr/src/linux ; tar -cf - COPYING CREDITS README tools include scripts Kbuild Makefile arch/*/{include,lib,Makefile} kernel/bpf lib) | tar -xf -
cp /usr/src/linux/LICENSES/preferred/GPL-2.0 .
sed -i -e 's/CFLAGS += -O2/CFLAGS = $(RPM_OPT_FLAGS)/' Makefile

%build
cd tools/lib/bpf
%if %{__isa_bits} == 64
%make_build CFLAGS="%{optflags}" LP64=1
%else
%make_build CFLAGS="%{optflags}"
%endif

%install
cd tools/lib/bpf
%if %{__isa_bits} == 64
%make_install prefix=/usr LP64=1
%else
%make_install prefix=/usr
%endif
make install_headers prefix=%{buildroot}/usr

rm -f %{buildroot}%{_libdir}/%{name}.a

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%{_libdir}/%{name}.so.%{sover_major}*

%files devel
%{_includedir}/bpf
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Jun  8 2020 mrostecki@suse.com
- Add python3 as a build dependency.
* Sun Feb  2 2020 mrostecki@opensuse.org
- Build libbpf from kernel sources, not from github sources, for
  consistency with bpftool package.
* Tue Jan  7 2020 tchvatal@suse.com
- Reflect SUSE CFLAGS
- Do not bother with obscpio if we are fetching direct releases
- Remove patch 0001-makefile-Fix-install-target.patch seems
  to build/install without it just fine
- Update to 0.0.6:
  + New features
  - new extensible bpf_object__open_{file,mem} APIs and
    DECLARE_LIBBPF_OPTS() macro to go with them
  - bpf_helpers.h, bpf_endian.h, and bpf_tracing.h are now
    distributed with libbpf
  - BPF CO-RE: added field size, field existence, and bitfield
    relocation support
  - BPF CO-RE: BPF_CORE_READ(), bpf_core_field_exists(),
    bpf_core_field_size() and other BPF CO-RE related helpers
    available through bpf_core_read.h header
  - bpf_object__open() API now auto-detects program type from
    its section name
  - BPF_PROG_TRACING programs support (incuding BTF-typed raw
    tracepoints, fentry/fexit programs)
  - mmap() support for BPF global variables
  - declarative map pinning support added
  - probe_read_{user,kernel}[_str]() BPF helpers added
  - bpf_get_link_xdp_info() function to get more XDP information
    added
  - a bunch of other AF_XDP changes
  + Usability improvements
  - no need for int version SEC('version') = 1; anymore
  - raw_tp/tp and uprobe/uretprobe section prefixes added
  - new bpf_program__get_{type,expected_attach_type} getters
  - preserve error code on program load failure
  + Fixes
  - btf_dump padding handling
  - bpf_object__name() returning name, not path
  - ELF section handling off-by-one bug fix
  - mem leak/double free fix in BPF program relocation code
* Tue Oct  1 2019 mrostecki@opensuse.org
- Initial release
